-----------------------------------------------------------
-- FPGA Training Board(B6101)
-- 8 Line Input to 7seg-LED Output Priority Encoder Circuit
-----------------------------------------------------------
-- File   : encode_8to7seg_vhdl_top.vhd
-- Date   : 2009-06-05
-- Family : Cyclone
-- Device : EP1C3T144C8
--
-- Designed by TOYO-LINX Co.,Ltd. / yKikuchi
-----------------------------------------------------------

library IEEE;
use IEEE.std_logic_1164.all;
use IEEE.std_logic_arith.all;
use IEEE.std_logic_unsigned.all;

entity encode_8to7seg_vhdl_top is
	port(
		LED_A	:	out std_logic;
		LED_B	:	out std_logic;
		LED_C	:	out std_logic;
		LED_D	:	out std_logic;
		LED_E	:	out std_logic;
		LED_F	:	out std_logic;
		LED_G	:	out std_logic;
		LED_DP	:	out std_logic;
		SW1		:	in std_logic;
		SW2		:	in std_logic;
		SW3		:	in std_logic;
		SW4		:	in std_logic;
		SW5		:	in std_logic;
		SW6		:	in std_logic;
		SW7		:	in std_logic
	);
end encode_8to7seg_vhdl_top;

architecture RTL of encode_8to7seg_vhdl_top is

	signal A	:	std_logic_vector(7 downto 1);
	signal Y	:	std_logic_vector(2 downto 0);
	signal LED	:	std_logic_vector(7 downto 0);

begin

	A(1) <= not SW1;
	A(2) <= not SW2;
	A(3) <= not SW3;
	A(4) <= not SW4;
	A(5) <= not SW5;
	A(6) <= not SW6;
	A(7) <= not SW7;

	process (A)
	begin
		if(A(7) = '1')		then	Y <= "111";
		elsif(A(6) = '1')	then	Y <= "110";
		elsif(A(5) = '1')	then	Y <= "101";
		elsif(A(4) = '1')	then	Y <= "100";
		elsif(A(3) = '1')	then	Y <= "011";
		elsif(A(2) = '1')	then	Y <= "010";
		elsif(A(1) = '1')	then	Y <= "001";
		else						Y <= "000";
		end if;
	end process;

	process (Y)
	begin
		case Y is
			when "000"	=>	LED <= "00111111";
			when "001"	=>	LED <= "00000110";
			when "010"	=>	LED <= "01011011";
			when "011"	=>	LED <= "01001111";
			when "100"	=>	LED <= "01100110";
			when "101"	=>	LED <= "01101101";
			when "110"	=>	LED <= "01111101";
			when "111"	=>	LED <= "00000111";
			when others	=>	null;
		end case;
	end process;

	LED_A  <= LED(0);
	LED_B  <= LED(1);
	LED_C  <= LED(2);
	LED_D  <= LED(3);
	LED_E  <= LED(4);
	LED_F  <= LED(5);
	LED_G  <= LED(6);
	LED_DP <= LED(7);
	
end RTL;
